import assert from 'assert';
import NumberUtil from '../src/NumberUtil.js';
import Language from '../src/Language.js';

describe('NumberUtil.js', function() {

  describe('#toLocaleString(date, languageCode)', function() {

    it('should return correctly the locale number for the "es" value', function() {
      var languageCode = Language.SPANISH;
      var number = 1_500;

      var expected = '1500';
      var result = NumberUtil.toLocaleString(number, languageCode);
      assert.deepStrictEqual(result, expected);
    });

    it('should return correctly the locale number for the "en" value', function() {
      var languageCode = Language.ENGLISH;
      var number = 3_200;

      var expected = '3,200';
      var result = NumberUtil.toLocaleString(number, languageCode);
      assert.deepStrictEqual(result, expected);
    });
  });

  describe('#addZero(number, maxLength)', function() {

    it('should add a single leading zero', () => {
      assert.strictEqual(NumberUtil.addZero(5, 2), '05');
      assert.strictEqual(NumberUtil.addZero(9, 2), '09');
      assert.strictEqual(NumberUtil.addZero(12), '12');
    });

    it('should add multiple leading zeros', () => {
      assert.strictEqual(NumberUtil.addZero(5, 3), '005');
      assert.strictEqual(NumberUtil.addZero(9, 3), '009');
      assert.strictEqual(NumberUtil.addZero(12, 3), '012');
      assert.strictEqual(NumberUtil.addZero(123, 5), '00123');
    });

    it('should not add extra zeros if number length exceeds maxLength', () => {
      assert.strictEqual(NumberUtil.addZero(456, 3), '456');
      assert.strictEqual(NumberUtil.addZero(12345, 5), '12345');
      assert.strictEqual(NumberUtil.addZero(999, 2), '999');
    });

    it('should handle zero as input', () => {
      assert.strictEqual(NumberUtil.addZero(0, 2), '00');
      assert.strictEqual(NumberUtil.addZero(0, 3), '000');
      assert.strictEqual(NumberUtil.addZero(0, 5), '00000');
    });

  });

});
