import assert from 'assert';
import StringListUtil from '../src/StringListUtil.js';

describe('StringListUtil.js', function() {

  describe('#largerFromList(list)', function() {

    it('zero when empty array', function() {
      var list = [];

      var expected = 0;
      var result = StringListUtil.largerFromList(list);

      assert.deepStrictEqual(result, expected);
    });

    it('same length', function() {
      var list = ['one', 'two'];

      var expected = 3;
      var result = StringListUtil.largerFromList(list);

      assert.deepStrictEqual(result, expected);
    });

    it('larger', function() {
      var list = ['one', 'very_large', 'large', 'important'];

      var expected = 10;
      var result = StringListUtil.largerFromList(list);

      assert.deepStrictEqual(result, expected);
    });

  });

  describe('#toLargerLength(list, emptySpaceSymbol)', function() {

    it('same when same', function() {
      var list = ['one', 'two'];

      var expected = ['one', 'two'];
      var result = StringListUtil.toLargerLength(list);

      assert.deepStrictEqual(result, expected);
    });

    it('add spaces', function() {
      var list = ['very_large', 'two'];

      var expected = ['very_large', 'two       '];
      var result = StringListUtil.toLargerLength(list);

      assert.deepStrictEqual(result, expected);
    });

    it('add dot', function() {
      var list = ['very_large', 'two'];

      var expected = ['very_large', 'two.......'];
      var result = StringListUtil.toLargerLength(list, '.');

      assert.deepStrictEqual(result, expected);
    });

    it('add spaces, multiple', function() {
      var list = ['very_large', 'two', 'three', 'four', 'five'];

      var expected = ['very_large', 'two       ', 'three     ', 'four      ', 'five      '];
      var result = StringListUtil.toLargerLength(list);

      assert.deepStrictEqual(result, expected);
    });

    it('add spaces, last one', function() {
      var list = ['two', 'three', 'four', 'five', 'very_large'];

      var expected = ['two       ', 'three     ', 'four      ', 'five      ', 'very_large'];
      var result = StringListUtil.toLargerLength(list);

      assert.deepStrictEqual(result, expected);
    });


  });

});
